summaryrefslogtreecommitdiffstats
path: root/libktorrent/expandablewidget.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit936370a6413e14b322ce808be07c6c66714941b6 (patch)
tree31b9f37bb64beac5eddafef05312da5b48736bd6 /libktorrent/expandablewidget.h
parent2a99db3ebc4c211e436f95fde24b5ac6826d0267 (diff)
downloadktorrent-936370a6413e14b322ce808be07c6c66714941b6.tar.gz
ktorrent-936370a6413e14b322ce808be07c6c66714941b6.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/ktorrent@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'libktorrent/expandablewidget.h')
-rw-r--r--libktorrent/expandablewidget.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/libktorrent/expandablewidget.h b/libktorrent/expandablewidget.h
index 02e6cf8..bf76dbb 100644
--- a/libktorrent/expandablewidget.h
+++ b/libktorrent/expandablewidget.h
@@ -48,23 +48,23 @@ namespace kt
/**
* Constructor, the first child must be provided.
* @param child The first child
* @param tqparent The tqparent
* @param name The name
*/
- ExpandableWidget(TQWidget* child,TQWidget *tqparent = 0, const char *name = 0);
+ ExpandableWidget(TQWidget* child,TQWidget *parent = 0, const char *name = 0);
virtual ~ExpandableWidget();
/**
* Expand the widget. This will ensure the proper tqparent child relations.
* @param w The widget
* @param pos It's position relative to the current widget
*/
void expand(TQWidget* w,Position pos);
/**
* Remove a widget. This will ensure the proper tqparent child relations.
* The widget w will become parentless. Note the first child will never be removed.
* @param w The widget
*/
@@ -48,23 +48,23 @@ namespace kt
* Constructor, the first child must be provided.
* @param child The first child
- * @param tqparent The tqparent
+ * @param parent The parent
* @param name The name
*/
@@ -48,23 +48,23 @@ namespace kt
virtual ~ExpandableWidget();
/**
- * Expand the widget. This will ensure the proper tqparent child relations.
+ * Expand the widget. This will ensure the proper parent child relations.
* @param w The widget
* @param pos It's position relative to the current widget
@@ -48,23 +48,23 @@ namespace kt
void expand(TQWidget* w,Position pos);
/**
- * Remove a widget. This will ensure the proper tqparent child relations.
+ * Remove a widget. This will ensure the proper parent child relations.
* The widget w will become parentless. Note the first child will never be removed.
* @param w The widget